@@ -40,7 +40,7 @@ extern "C" {
     #define CL_CALLBACK
 #endif
 
-#if 0
+#ifdef __APPLE__
     #define CL_EXTENSION_WEAK_LINK                  __attribute__((weak_import))
     #define CL_API_SUFFIX__VERSION_1_0
     #define CL_EXT_SUFFIX__VERSION_1_0              CL_EXTENSION_WEAK_LINK
@@ -269,8 +269,7 @@ typedef unsigned int cl_GLenum;
  */
 
 /* Define basic vector types */
-#if 0
-   #include <altivec.h>   /* may be omitted depending on compiler. AltiVec spec provides no way to detect whether the header is required. */
+#if defined( __VEC__ )
    typedef vector unsigned char     __cl_uchar16;
    typedef vector signed char       __cl_char16;
    typedef vector unsigned short    __cl_ushort8;
